@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2016 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -241,7 +241,7 @@ Icmp6::Recv(void)
 
     debugs(42, 8, HERE << n << " bytes from " << preply.from);
 
-// FIXME INET6 : The IPv6 Header (ip6_hdr) is not availble directly >:-(
+// XXX: The IPv6 Header (ip6_hdr) is not available directly
 //
 // TTL still has to come from the IP header somewhere.
 //  still need to strip and process it properly.
@@ -258,7 +258,7 @@ Icmp6::Recv(void)
     #define ip6_hops    // HOPS!!!  (can it be true??)
 
         ip = (struct ip6_hdr *) pkt;
-        FIXME  += sizeof(ip6_hdr);
+        //  += sizeof(ip6_hdr);
 
     debugs(42, DBG_CRITICAL, HERE << "ip6_nxt=" << ip->ip6_nxt <<
             ", ip6_plen=" << ip->ip6_plen <<
@@ -302,9 +302,9 @@ Icmp6::Recv(void)
     preply.rtt = tvSubMsec(tv, now);
 
     /*
-     * FIXME INET6: Without access to the IPv6-Hops header we must rely on the total RTT
-     *      and could caculate the hops from that, but it produces some weird value mappings using ipHops
-     *  for now everything is 1 v6 hop away with variant RTT
+     * Without access to the IPv6-Hops header we must rely on the total RTT
+     * and could calculate the hops from that, but it produces some weird value mappings using ipHops
+     * for now everything is 1 v6 hop away with variant RTT
      * WANT:    preply.hops = ip->ip6_hops; // ipHops(ip->ip_hops);
      */
     preply.hops = 1;
