@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2019 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -172,7 +172,7 @@ IcmpPinger::Recv(void)
     if (n < 0) {
         debugs(42, DBG_IMPORTANT, "Pinger exiting.");
         Close();
-        exit(1);
+        exit(EXIT_FAILURE);
     }
 
     if (0 == n) {
@@ -180,7 +180,7 @@ IcmpPinger::Recv(void)
         debugs(42, DBG_CRITICAL, "EOF encountered. Pinger exiting.");
         errno = 0;
         Close();
-        exit(1);
+        exit(EXIT_FAILURE);
     }
 
     guess_size = n - (sizeof(pingerEchoData) - PINGER_PAYLOAD_SZ);
@@ -221,7 +221,7 @@ IcmpPinger::SendResult(pingerReplyData &preply, int len)
         int xerrno = errno;
         debugs(42, DBG_CRITICAL, "pinger: FATAL error on send: " << xstrerr(xerrno));
         Close();
-        exit(1);
+        exit(EXIT_FAILURE);
     }
 }
 
